/* main.cc
 * Copyright (C) 2001 The University of Newcastle upon Tyne
 *
 * Written by Paul Coates (Paul.Coates@ncl.ac.uk)
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
 * 02111-1307, USA.
 */

#include <glade/glade.h>
#include <gnome.h>
#include <stdlib.h>
#include <string.h>
#include <unistd.h>
#include <pwd.h>
#include "main.h"
#include "gui.h"
#include "monitor.h"
#include "session.h"
#include "scheduler.h"
#include "parser.h"
#include "header.h"

int main(int argc, char *argv[])
{
	Main m(argc, argv);
	return 0;
}

gint timeout_cb(gpointer data)
{ ((Main*)data)->timeout_callback(); return TRUE; }
gint init_cb(gpointer data)
{ ((Main*)data)->init_callback(); return FALSE; }

Main::Main(int argc, char *argv[])
{
	scheduler = new Scheduler(this);
	parser = new Parser(this);

	gnome_init("nomad", VERSION, argc, argv);
//	gconf_init (argc, argv, NULL);
	glade_gnome_init();
	gdk_rgb_init ();
	session = new Session(this);
	gui = new Gui(this);
	gtk_timeout_add(2000, timeout_cb, this);
	gtk_timeout_add(0, init_cb, this);
	gtk_main();
}

Main::~Main()
{
	if (session!=NULL) delete session;
	if (scheduler!=NULL) delete scheduler;
	if (parser!=NULL) delete parser;
	if (gui!=NULL) delete gui;
}

void Main::init_callback()
{
	gchar *str;

	str = gnome_config_get_string("/nomad/session/startup");

	gui->monitor->show();
	if ((str!=NULL) && (strcmp(str, "")!=0))
		session->load_session(str);
	g_free(str);
}

void Main::timeout_callback()
{
	scheduler->timeout();
}

void Main::setTitle()
{
	char buf[256], flag1[4], flag2[4];

	strcpy(flag1, (session->dirty=='y')?"* ":"");
	strcpy(flag2, (strcmp(session->session_name, "")!=0)?" - ":"");
	sprintf(buf, "%sNomad%s%s", flag1, flag2, session->session_name);
	gtk_window_set_title(GTK_WINDOW(gui->monitor->mainwindow), buf);
}

void Main::update()
{
	gui->update_lists();
}

void Main::quit()
{
	session->quit_session();
	gtk_exit(0);
}

